#[repr(u8)]pub enum InvalBit {
VALID = 0,
INVALID = 1,
}Variants
VALID = 0
Time and date counters can be read or written. Time and date is valid.
INVALID = 1
Time and date counter values are changing or time and date is invalid and cannot be read or written.
Implementations